/*===========================================================================*/
/*   (Tvector/cnst.scm)                                                      */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Tvector/cnst.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_TVECTOR_CNST_TYPE_DEFINITIONS
#define BGL_TVECTOR_CNST_TYPE_DEFINITIONS

/* object type definitions */
	typedef struct BgL_typez00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_idz00;
		obj_t BgL_namez00;
		obj_t BgL_siza7eza7;
		obj_t BgL_classz00;
		obj_t BgL_coercezd2tozd2;
		obj_t BgL_parentsz00;
		bool_t BgL_initzf3zf3;
		bool_t BgL_magiczf3zf3;
		obj_t BgL_nullz00;
		obj_t BgL_z42z42;
		obj_t BgL_aliasz00;
		obj_t BgL_pointedzd2tozd2byz00;
		obj_t BgL_tvectorz00;
		obj_t BgL_locationz00;
		obj_t BgL_importzd2locationzd2;
		int BgL_occurrencez00;
	}              *BgL_typez00_bglt;

	typedef struct BgL_tvecz00_bgl
	{
		struct BgL_typez00_bgl *BgL_itemzd2typezd2;
	}              *BgL_tvecz00_bglt;


#endif													// BGL_TVECTOR_CNST_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	extern obj_t BGl_za2intza2z00zztype_cachez00;
	static obj_t BGl_requirezd2initializa7ationz75zztvector_cnstz00 = BUNSPEC;
	BGL_IMPORT obj_t bgl_display_obj(obj_t, obj_t);
	BGL_EXPORTED_DECL bool_t
		BGl_tvectorzd2Czd2staticzf3zf3zztvector_cnstz00(obj_t);
	static obj_t BGl_toplevelzd2initzd2zztvector_cnstz00(void);
	static obj_t BGl_genericzd2initzd2zztvector_cnstz00(void);
	static obj_t BGl_objectzd2initzd2zztvector_cnstz00(void);
	extern obj_t BGl_za2boolza2z00zztype_cachez00;
	static obj_t BGl_z62tvectorzd2ze3czd2vectorz81zztvector_cnstz00(obj_t, obj_t);
	extern obj_t BGl_za2longza2z00zztype_cachez00;
	extern obj_t BGl_za2stringza2z00zztype_cachez00;
	static obj_t BGl_methodzd2initzd2zztvector_cnstz00(void);
	extern obj_t BGl_za2realza2z00zztype_cachez00;
	static obj_t BGl_z62zc3z04anonymousza31075ze3ze5zztvector_cnstz00(obj_t,
		obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2outputzd2stringz00zz__r4_ports_6_10_1z00(obj_t);
	static obj_t BGl_z62zc3z04anonymousza31084ze3ze5zztvector_cnstz00(obj_t,
		obj_t, obj_t);
	BGL_IMPORT obj_t BGl_errorz00zz__errorz00(obj_t, obj_t, obj_t);
	BGL_IMPORT obj_t bgl_close_output_port(obj_t);
	static obj_t BGl_z62tvectorzd2Czd2staticzf3z91zztvector_cnstz00(obj_t, obj_t);
	static obj_t BGl_tvectorzd2czd2printerz00zztvector_cnstz00(obj_t);
	BGL_EXPORTED_DECL obj_t
		BGl_modulezd2initializa7ationz75zztvector_cnstz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztvector_tvectorz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_cachez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_envz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_vectors_6_8z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_characters_6_6z00(long, char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__objectz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__structurez00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__errorz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__biglooz00(long, char *);
	static obj_t BGl_libraryzd2moduleszd2initz00zztvector_cnstz00(void);
	static obj_t BGl_importedzd2moduleszd2initz00zztvector_cnstz00(void);
	static obj_t BGl_gczd2rootszd2initz00zztvector_cnstz00(void);
	BGL_EXPORTED_DECL obj_t
		BGl_tvectorzd2ze3czd2vectorze3zztvector_cnstz00(obj_t);
	extern obj_t BGl_za2charza2z00zztype_cachez00;
	static obj_t *__cnst;


	   
		 
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_tvectorzd2Czd2staticzf3zd2envz21zztvector_cnstz00,
		BgL_bgl_za762tvectorza7d2cza7d1128za7,
		BGl_z62tvectorzd2Czd2staticzf3z91zztvector_cnstz00, 0L, BUNSPEC, 1);
	     
		DEFINE_EXPORT_BGL_PROCEDURE
		(BGl_tvectorzd2ze3czd2vectorzd2envz31zztvector_cnstz00,
		BgL_bgl_za762tvectorza7d2za7e31129za7,
		BGl_z62tvectorzd2ze3czd2vectorz81zztvector_cnstz00, 0L, BUNSPEC, 1);
	BGL_IMPORT obj_t BGl_displayzd2envzd2zz__r4_output_6_10_3z00;
	BGL_IMPORT obj_t BGl_writezd2envzd2zz__r4_output_6_10_3z00;
	   
		 
		DEFINE_STRING(BGl_string1121z00zztvector_cnstz00,
		BgL_bgl_string1121za700za7za7t1130za7, "tvector-c-printer", 17);
	      DEFINE_STRING(BGl_string1122z00zztvector_cnstz00,
		BgL_bgl_string1122za700za7za7t1131za7,
		"This tvector can't not be compiled as a static C vector", 55);
	      DEFINE_STRING(BGl_string1123z00zztvector_cnstz00,
		BgL_bgl_string1123za700za7za7t1132za7, "(unsigned char)", 15);
	      DEFINE_STRING(BGl_string1124z00zztvector_cnstz00,
		BgL_bgl_string1124za700za7za7t1133za7, "1", 1);
	      DEFINE_STRING(BGl_string1125z00zztvector_cnstz00,
		BgL_bgl_string1125za700za7za7t1134za7, "0", 1);
	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1119z00zztvector_cnstz00,
		BgL_bgl_za762za7c3za704anonymo1135za7,
		BGl_z62zc3z04anonymousza31075ze3ze5zztvector_cnstz00, 0L, BUNSPEC, 2);
	      DEFINE_STRING(BGl_string1126z00zztvector_cnstz00,
		BgL_bgl_string1126za700za7za7t1136za7, ", ", 2);
	      DEFINE_STRING(BGl_string1127z00zztvector_cnstz00,
		BgL_bgl_string1127za700za7za7t1137za7, "tvector_cnst", 12);
	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1120z00zztvector_cnstz00,
		BgL_bgl_za762za7c3za704anonymo1138za7,
		BGl_z62zc3z04anonymousza31084ze3ze5zztvector_cnstz00, 0L, BUNSPEC, 2);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		   
			 ADD_ROOT((void *) (&BGl_requirezd2initializa7ationz75zztvector_cnstz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zztvector_cnstz00(long
		BgL_checksumz00_245, char *BgL_fromz00_246)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zztvector_cnstz00))
				{
					BGl_requirezd2initializa7ationz75zztvector_cnstz00 =
						BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zztvector_cnstz00();
					BGl_libraryzd2moduleszd2initz00zztvector_cnstz00();
					BGl_importedzd2moduleszd2initz00zztvector_cnstz00();
					return BGl_toplevelzd2initzd2zztvector_cnstz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			BGl_modulezd2initializa7ationz75zz__r4_output_6_10_3z00(0L,
				"tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L,
				"tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__errorz00(0L, "tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
				"tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__r4_vectors_6_8z00(0L, "tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__r4_characters_6_6z00(0L,
				"tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__objectz00(0L, "tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__structurez00(0L, "tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__biglooz00(0L, "tvector_cnst");
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "tvector_cnst");
			return BUNSPEC;
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			return bgl_gc_roots_register();
		}

	}



/* toplevel-init */
	obj_t BGl_toplevelzd2initzd2zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			return BUNSPEC;
		}

	}



/* tvector-C-static? */
	BGL_EXPORTED_DEF bool_t BGl_tvectorzd2Czd2staticzf3zf3zztvector_cnstz00(obj_t
		BgL_tvectz00_13)
	{
		{	/* Tvector/cnst.scm 30 */
			{	/* Tvector/cnst.scm 31 */
				obj_t BgL_itypez00_156;

				{	/* Tvector/cnst.scm 31 */
					BgL_typez00_bglt BgL_oz00_194;

					BgL_oz00_194 =
						((BgL_typez00_bglt)
						STRUCT_REF(((obj_t) BgL_tvectz00_13), (int) (0L)));
					{
						BgL_typez00_bglt BgL_auxz00_269;

						{
							BgL_tvecz00_bglt BgL_auxz00_270;

							{
								obj_t BgL_auxz00_271;

								{	/* Tvector/cnst.scm 31 */
									BgL_objectz00_bglt BgL_tmpz00_272;

									BgL_tmpz00_272 = ((BgL_objectz00_bglt) BgL_oz00_194);
									BgL_auxz00_271 = BGL_OBJECT_WIDENING(BgL_tmpz00_272);
								}
								BgL_auxz00_270 = ((BgL_tvecz00_bglt) BgL_auxz00_271);
							}
							BgL_auxz00_269 =
								(((BgL_tvecz00_bglt) COBJECT(BgL_auxz00_270))->
								BgL_itemzd2typezd2);
						}
						BgL_itypez00_156 = ((obj_t) BgL_auxz00_269);
				}}
				if ((BgL_itypez00_156 == BGl_za2longza2z00zztype_cachez00))
					{	/* Tvector/cnst.scm 33 */
						return ((bool_t) 1);
					}
				else
					{	/* Tvector/cnst.scm 33 */
						if ((BgL_itypez00_156 == BGl_za2intza2z00zztype_cachez00))
							{	/* Tvector/cnst.scm 34 */
								return ((bool_t) 1);
							}
						else
							{	/* Tvector/cnst.scm 34 */
								if ((BgL_itypez00_156 == BGl_za2charza2z00zztype_cachez00))
									{	/* Tvector/cnst.scm 35 */
										return ((bool_t) 1);
									}
								else
									{	/* Tvector/cnst.scm 35 */
										if ((BgL_itypez00_156 == BGl_za2boolza2z00zztype_cachez00))
											{	/* Tvector/cnst.scm 36 */
												return ((bool_t) 1);
											}
										else
											{	/* Tvector/cnst.scm 36 */
												if (
													(BgL_itypez00_156 ==
														BGl_za2stringza2z00zztype_cachez00))
													{	/* Tvector/cnst.scm 37 */
														return ((bool_t) 1);
													}
												else
													{	/* Tvector/cnst.scm 37 */
														return
															(BgL_itypez00_156 ==
															BGl_za2realza2z00zztype_cachez00);
													}
											}
									}
							}
					}
			}
		}

	}



/* &tvector-C-static? */
	obj_t BGl_z62tvectorzd2Czd2staticzf3z91zztvector_cnstz00(obj_t BgL_envz00_225,
		obj_t BgL_tvectz00_226)
	{
		{	/* Tvector/cnst.scm 30 */
			return
				BBOOL(BGl_tvectorzd2Czd2staticzf3zf3zztvector_cnstz00
				(BgL_tvectz00_226));
		}

	}



/* tvector-c-printer */
	obj_t BGl_tvectorzd2czd2printerz00zztvector_cnstz00(obj_t BgL_tvectz00_14)
	{
		{	/* Tvector/cnst.scm 44 */
			{	/* Tvector/cnst.scm 45 */
				obj_t BgL_itypez00_158;

				{	/* Tvector/cnst.scm 45 */
					BgL_typez00_bglt BgL_oz00_197;

					BgL_oz00_197 =
						((BgL_typez00_bglt)
						STRUCT_REF(((obj_t) BgL_tvectz00_14), (int) (0L)));
					{
						BgL_typez00_bglt BgL_auxz00_295;

						{
							BgL_tvecz00_bglt BgL_auxz00_296;

							{
								obj_t BgL_auxz00_297;

								{	/* Tvector/cnst.scm 45 */
									BgL_objectz00_bglt BgL_tmpz00_298;

									BgL_tmpz00_298 = ((BgL_objectz00_bglt) BgL_oz00_197);
									BgL_auxz00_297 = BGL_OBJECT_WIDENING(BgL_tmpz00_298);
								}
								BgL_auxz00_296 = ((BgL_tvecz00_bglt) BgL_auxz00_297);
							}
							BgL_auxz00_295 =
								(((BgL_tvecz00_bglt) COBJECT(BgL_auxz00_296))->
								BgL_itemzd2typezd2);
						}
						BgL_itypez00_158 = ((obj_t) BgL_auxz00_295);
				}}
				if ((BgL_itypez00_158 == BGl_za2longza2z00zztype_cachez00))
					{	/* Tvector/cnst.scm 47 */
						return BGl_displayzd2envzd2zz__r4_output_6_10_3z00;
					}
				else
					{	/* Tvector/cnst.scm 47 */
						if ((BgL_itypez00_158 == BGl_za2intza2z00zztype_cachez00))
							{	/* Tvector/cnst.scm 48 */
								return BGl_displayzd2envzd2zz__r4_output_6_10_3z00;
							}
						else
							{	/* Tvector/cnst.scm 48 */
								if ((BgL_itypez00_158 == BGl_za2charza2z00zztype_cachez00))
									{	/* Tvector/cnst.scm 49 */
										return BGl_proc1119z00zztvector_cnstz00;
									}
								else
									{	/* Tvector/cnst.scm 49 */
										if ((BgL_itypez00_158 == BGl_za2boolza2z00zztype_cachez00))
											{	/* Tvector/cnst.scm 52 */
												return BGl_proc1120z00zztvector_cnstz00;
											}
										else
											{	/* Tvector/cnst.scm 52 */
												if (
													(BgL_itypez00_158 ==
														BGl_za2stringza2z00zztype_cachez00))
													{	/* Tvector/cnst.scm 56 */
														return BGl_writezd2envzd2zz__r4_output_6_10_3z00;
													}
												else
													{	/* Tvector/cnst.scm 56 */
														if (
															(BgL_itypez00_158 ==
																BGl_za2realza2z00zztype_cachez00))
															{	/* Tvector/cnst.scm 57 */
																return
																	BGl_displayzd2envzd2zz__r4_output_6_10_3z00;
															}
														else
															{	/* Tvector/cnst.scm 57 */
																return
																	BGl_errorz00zz__errorz00
																	(BGl_string1121z00zztvector_cnstz00,
																	BGl_string1122z00zztvector_cnstz00,
																	BgL_tvectz00_14);
															}
													}
											}
									}
							}
					}
			}
		}

	}



/* &<@anonymous:1075> */
	obj_t BGl_z62zc3z04anonymousza31075ze3ze5zztvector_cnstz00(obj_t
		BgL_envz00_229, obj_t BgL_xz00_230, obj_t BgL_portz00_231)
	{
		{	/* Tvector/cnst.scm 49 */
			{	/* Tvector/cnst.scm 50 */
				obj_t BgL_tmpz00_317;

				BgL_tmpz00_317 = ((obj_t) BgL_portz00_231);
				bgl_display_string(BGl_string1123z00zztvector_cnstz00, BgL_tmpz00_317);
			}
			{	/* Tvector/cnst.scm 51 */
				long BgL_arg1083z00_244;

				BgL_arg1083z00_244 = (CCHAR(BgL_xz00_230));
				return bgl_display_obj(BINT(BgL_arg1083z00_244), BgL_portz00_231);
			}
		}

	}



/* &<@anonymous:1084> */
	obj_t BGl_z62zc3z04anonymousza31084ze3ze5zztvector_cnstz00(obj_t
		BgL_envz00_232, obj_t BgL_xz00_233, obj_t BgL_portz00_234)
	{
		{	/* Tvector/cnst.scm 52 */
			if (CBOOL(BgL_xz00_233))
				{	/* Tvector/cnst.scm 54 */
					obj_t BgL_tmpz00_326;

					BgL_tmpz00_326 = ((obj_t) BgL_portz00_234);
					return
						bgl_display_string(BGl_string1124z00zztvector_cnstz00,
						BgL_tmpz00_326);
				}
			else
				{	/* Tvector/cnst.scm 55 */
					obj_t BgL_tmpz00_329;

					BgL_tmpz00_329 = ((obj_t) BgL_portz00_234);
					return
						bgl_display_string(BGl_string1125z00zztvector_cnstz00,
						BgL_tmpz00_329);
				}
		}

	}



/* tvector->c-vector */
	BGL_EXPORTED_DEF obj_t BGl_tvectorzd2ze3czd2vectorze3zztvector_cnstz00(obj_t
		BgL_tvectorz00_15)
	{
		{	/* Tvector/cnst.scm 65 */
			{	/* Tvector/cnst.scm 66 */
				obj_t BgL_vectz00_167;

				BgL_vectz00_167 = STRUCT_REF(((obj_t) BgL_tvectorz00_15), (int) (1L));
				{	/* Tvector/cnst.scm 66 */
					obj_t BgL_czd2printerzd2_168;

					BgL_czd2printerzd2_168 =
						BGl_tvectorzd2czd2printerz00zztvector_cnstz00(BgL_tvectorz00_15);
					{	/* Tvector/cnst.scm 67 */
						long BgL_lenzd21zd2_169;

						BgL_lenzd21zd2_169 =
							(VECTOR_LENGTH(((obj_t) BgL_vectz00_167)) - 1L);
						{	/* Tvector/cnst.scm 68 */
							obj_t BgL_portz00_170;

							{	/* Tvector/cnst.scm 69 */

								{	/* Tvector/cnst.scm 69 */

									BgL_portz00_170 =
										BGl_openzd2outputzd2stringz00zz__r4_ports_6_10_1z00(BTRUE);
							}}
							{	/* Tvector/cnst.scm 69 */

								bgl_display_char(((unsigned char) '{'), BgL_portz00_170);
								{
									long BgL_iz00_172;

									BgL_iz00_172 = 0L;
								BgL_zc3z04anonymousza31096ze3z87_173:
									if ((BgL_iz00_172 == BgL_lenzd21zd2_169))
										{	/* Tvector/cnst.scm 72 */
											{	/* Tvector/cnst.scm 74 */
												obj_t BgL_arg1098z00_175;

												BgL_arg1098z00_175 =
													VECTOR_REF(((obj_t) BgL_vectz00_167), BgL_iz00_172);
												BGL_PROCEDURE_CALL2(BgL_czd2printerzd2_168,
													BgL_arg1098z00_175, BgL_portz00_170);
											}
											bgl_display_char(((unsigned char) '}'), BgL_portz00_170);
											return bgl_close_output_port(BgL_portz00_170);
										}
									else
										{	/* Tvector/cnst.scm 72 */
											{	/* Tvector/cnst.scm 78 */
												obj_t BgL_arg1103z00_176;

												BgL_arg1103z00_176 =
													VECTOR_REF(((obj_t) BgL_vectz00_167), BgL_iz00_172);
												BGL_PROCEDURE_CALL2(BgL_czd2printerzd2_168,
													BgL_arg1103z00_176, BgL_portz00_170);
											}
											bgl_display_string(BGl_string1126z00zztvector_cnstz00,
												BgL_portz00_170);
											{
												long BgL_iz00_360;

												BgL_iz00_360 = (BgL_iz00_172 + 1L);
												BgL_iz00_172 = BgL_iz00_360;
												goto BgL_zc3z04anonymousza31096ze3z87_173;
											}
										}
								}
							}
						}
					}
				}
			}
		}

	}



/* &tvector->c-vector */
	obj_t BGl_z62tvectorzd2ze3czd2vectorz81zztvector_cnstz00(obj_t BgL_envz00_241,
		obj_t BgL_tvectorz00_242)
	{
		{	/* Tvector/cnst.scm 65 */
			return
				BGl_tvectorzd2ze3czd2vectorze3zztvector_cnstz00(BgL_tvectorz00_242);
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zztvector_cnstz00(void)
	{
		{	/* Tvector/cnst.scm 15 */
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string1127z00zztvector_cnstz00));
			BGl_modulezd2initializa7ationz75zztype_envz00(296457443L,
				BSTRING_TO_STRING(BGl_string1127z00zztvector_cnstz00));
			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
				BSTRING_TO_STRING(BGl_string1127z00zztvector_cnstz00));
			return
				BGl_modulezd2initializa7ationz75zztvector_tvectorz00(501518119L,
				BSTRING_TO_STRING(BGl_string1127z00zztvector_cnstz00));
		}

	}

#ifdef __cplusplus
}
#endif
